"use strict";
var Future = require("fibers/future");
function isWindows() {
    return process.platform === "win32";
}
exports.isWindows = isWindows;
function isWindows64() {
    return isWindows() && (process.arch === "x64" || process.env.hasOwnProperty("PROCESSOR_ARCHITEW6432"));
}
exports.isWindows64 = isWindows64;
function isWindows32() {
    return isWindows() && !isWindows64();
}
exports.isWindows32 = isWindows32;
function isDarwin() {
    return process.platform === "darwin";
}
exports.isDarwin = isDarwin;
function isLinux() {
    return process.platform === "linux";
}
exports.isLinux = isLinux;
function isLinux64() {
    return isLinux() && process.config.variables.host_arch === "x64";
}
exports.isLinux64 = isLinux64;
function dotNetVersion(message) {
    if (isWindows()) {
        var result = new Future();
        var Winreg = require("winreg");
        var regKey = new Winreg({
            hive: Winreg.HKLM,
            key: '\\Software\\Microsoft\\NET Framework Setup\\NDP\\v4\\Client'
        });
        regKey.get("Version", function (err, value) {
            if (err) {
                result.throw(new Error(message));
            }
            else {
                result.return(value.value);
            }
        });
        return result;
    }
    else {
        return Future.fromResult(null);
    }
}
exports.dotNetVersion = dotNetVersion;
function isDotNet40Installed(message) {
    return (function () {
        if (isWindows()) {
            try {
                dotNetVersion(message || "An error occurred while reading the registry.").wait();
                return true;
            }
            catch (e) {
                return false;
            }
        }
        else {
            return false;
        }
    }).future()();
}
exports.isDotNet40Installed = isDotNet40Installed;
